@@ -17,6 +17,7 @@
 from __future__ import annotations
 
 import copy
+import json
 import logging
 import os
 import secrets
@@ -36,8 +37,8 @@ from streamlit.errors import StreamlitAPIException
 # Descriptions of each of the possible config sections.
 # (We use OrderedDict to make the order in which sections are declared in this
 # file be the same order as the sections appear with `streamlit config show`)
-_section_descriptions: dict[str, str] = OrderedDict(
-    _test="Special test section just used for unit tests."
+_section_descriptions: OrderedDict[str, str] = OrderedDict(  # ty: ignore
+    _test="Special test section just used for unit tests."  # ty: ignore
 )
 
 # Ensures that we don't try to get or set config options when config.toml files
@@ -710,7 +711,7 @@ _create_option(
 
         Allowed values:
         - "auto"     : Streamlit will attempt to use the watchdog module, and
-                       falls back to polling if watchdog is not available.
+                       falls back to polling if watchdog isn't available.
         - "watchdog" : Force Streamlit to use the watchdog module.
         - "poll"     : Force Streamlit to always use polling.
         - "none"     : Streamlit will not watch files.
@@ -747,6 +748,17 @@ def _server_headless() -> bool:
     )
 
 
+_create_option(
+    "server.showEmailPrompt",
+    description="""
+        Whether to show a terminal prompt for the user's email address when
+        they run Streamlit (locally) for the first time. If you set
+        `server.headless=True`, Streamlit will not show this prompt.
+    """,
+    default_val=True,
+    type_=bool,
+)
+
 _create_option(
     "server.runOnSave",
     description="""
@@ -814,6 +826,19 @@ _create_option(
     type_=str,
 )
 
+_create_option(
+    "server.customComponentBaseUrlPath",
+    description="""
+        The base path for the URL where Streamlit should serve custom
+        components. If this config var is set and a call to ``declare_component``
+        does not specify a URL, the component's URL will be set to
+        ``f"{server.customComponentBaseUrlPath}/{component_name}/"``.
+    """,
+    default_val="",
+    type_=str,
+    visibility="hidden",
+)
+
 # TODO: Rename to server.enableCorsProtection.
 _create_option(
     "server.enableCORS",
@@ -901,6 +926,24 @@ _create_option(
     type_=bool,
 )
 
+_create_option(
+    "server.websocketPingInterval",
+    description="""
+        The interval (in seconds) at which the server pings the client to keep
+        the websocket connection alive.
+
+        The default value should work for most deployments. However, if you're
+        experiencing frequent disconnections in certain proxy setups (e.g.,
+        "Connection error" messages), you may want to try adjusting this value.
+
+        Note: When you set this option, Streamlit automatically sets the ping
+        timeout to match this interval. For Tornado >=6.5, a value less than 30
+        may cause connection issues.
+    """,
+    default_val=None,
+    type_=int,
+)
+
 _create_option(
     "server.enableStaticServing",
     description="""
@@ -918,12 +961,39 @@ _create_option(
 
         The server may choose to clean up session state, uploaded files, etc
         for a given session with no active websocket connection at any point
-        after this time has passed.
+        after this time has passed. If you are using load balancing or
+        replication in your deployment, you must enable session stickiness
+        in your proxy to guarantee reconnection to the existing session. For
+        more information, see https://docs.streamlit.io/replication.
     """,
     default_val=120,
     type_=int,
 )
 
+_create_option(
+    "server.trustedUserHeaders",
+    description="""
+        HTTP headers to embed in st.user.
+
+        Configures HTTP headers whose values, on websocket connect, will be saved in
+        st.user. Each key is the header name to map, and each value is the key in
+        st.user to save the value under. If the configured header occurs multiple times
+        in the request, the first value will be used. Multiple headers may not point to
+        the same user key, and an error will be thrown on initialization if this is
+        done.
+
+        If configured using an environment variable or CLI option, it should be a
+        single JSON-formatted dict of string-to-string.
+
+        Note: This is an experimental API subject to change.
+    """,
+    default_val={},
+    # This is used by click. We accept a JSON string, so this is a str.
+    type_=str,
+    # Hide until API is finalized.
+    visibility="hidden",
+)
+
 # Config Section: Browser #
 
 _create_section("browser", "Configuration of non-UI browser options.")
@@ -1133,6 +1203,15 @@ _create_theme_options(
     """,
 )
 
+_create_theme_options(
+    "linkUnderline",
+    categories=["theme", CustomThemeCategories.SIDEBAR],
+    description="""
+        Whether or not links should be displayed with an underline.
+    """,
+    type_=bool,
+)
+
 _create_theme_options(
     "codeBackgroundColor",
     categories=["theme", CustomThemeCategories.SIDEBAR],
@@ -1161,53 +1240,6 @@ _create_theme_options(
     """,
 )
 
-_create_theme_options(
-    "codeFont",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
-    description="""
-        The font family to use for code (monospace) in the sidebar.
-
-        This can be one of the following:
-        - "sans-serif"
-        - "serif"
-        - "monospace"
-        - The `family` value for a custom font table under [[theme.fontFaces]]
-        - A comma-separated list of these (as a single string) to specify
-          fallbacks
-    """,
-)
-
-_create_theme_options(
-    "codeFontSize",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
-    description="""
-        Sets the font size (in pixels or rem) for code blocks and code text.
-
-        This applies to code blocks (ex: `st.code`), as well as font in `st.json` and `st.help`.
-        It does not apply to inline code, which is set by default to 0.75em.
-
-        When unset, the code font size will be 0.875rem.
-    """,
-)
-
-_create_theme_options(
-    "headingFont",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
-    description="""
-        The font family to use for headings.
-
-        This can be one of the following:
-        - "sans-serif"
-        - "serif"
-        - "monospace"
-        - The `family` value for a custom font table under [[theme.fontFaces]]
-        - A comma-separated list of these (as a single string) to specify
-          fallbacks
-
-        If no heading font is set, Streamlit uses `theme.font` for headings.
-    """,
-)
-
 _create_theme_options(
     "fontFaces",
     categories=["theme"],
@@ -1239,6 +1271,158 @@ _create_theme_options(
     """,
 )
 
+_create_theme_options(
+    "baseFontSize",
+    categories=["theme"],
+    description="""
+        The root font size (in pixels) for the app.
+
+        This determines the overall scale of text and UI elements. This is a
+        positive integer.
+
+        If this isn't set, the font size will be 16px.
+    """,
+    type_=int,
+)
+
+_create_theme_options(
+    "baseFontWeight",
+    categories=["theme"],
+    description="""
+        The root font weight for the app.
+
+        This determines the overall weight of text and UI elements. This is an
+        integer multiple of 100. Values can be between 100 and 600, inclusive.
+
+        If this isn't set, the font weight will be set to 400 (normal weight).
+    """,
+    type_=int,
+)
+
+_create_theme_options(
+    "headingFont",
+    categories=["theme", CustomThemeCategories.SIDEBAR],
+    description="""
+        The font family to use for headings.
+
+        This can be one of the following:
+        - "sans-serif"
+        - "serif"
+        - "monospace"
+        - The `family` value for a custom font table under [[theme.fontFaces]]
+        - A comma-separated list of these (as a single string) to specify
+          fallbacks
+
+        If this isn't set, Streamlit uses `theme.font` for headings.
+    """,
+)
+
+_create_theme_options(
+    "headingFontSizes",
+    categories=["theme", CustomThemeCategories.SIDEBAR],
+    description="""
+        One or more font sizes for h1-h6 headings.
+
+        If no sizes are set, Streamlit will use the default sizes for h1-h6
+        headings. Heading font sizes set in [theme] are not inherited by
+        [theme.sidebar]. The following sizes are used by default:
+        [
+            "2.75rem", # h1 (1.5rem for sidebar)
+            "2.25rem", # h2 (1.25rem for sidebar)
+            "1.75rem", # h3 (1.125rem for sidebar)
+            "1.5rem",  # h4 (1rem for sidebar)
+            "1.25rem", # h5 (0.875rem for sidebar)
+            "1rem",    # h6 (0.75rem for sidebar)
+        ]
+
+        If you specify an array with fewer than six sizes, the unspecified
+        heading sizes will be the default values. For example, you can use the
+        following array to set the font sizes for h1-h3 headings while keeping
+        h4-h6 headings at their default sizes:
+            headingFontSizes = ["3rem", "2.875rem", "2.75rem"]
+
+        Setting a single value (not in an array) will set the font size for all
+        h1-h6 headings to that value:
+            headingFontSizes = "2.75rem"
+
+        Font sizes can be specified in pixels or rem, but rem is recommended.
+    """,
+)
+
+_create_theme_options(
+    "headingFontWeights",
+    categories=["theme", CustomThemeCategories.SIDEBAR],
+    description="""
+        One or more font weights for h1-h6 headings.
+
+        If no weights are set, Streamlit will use the default weights for h1-h6
+        headings. Heading font weights set in [theme] are not inherited by
+        [theme.sidebar]. The following weights are used by default:
+        [
+            700, # h1 (bold)
+            600, # h2 (semi-bold)
+            600, # h3 (semi-bold)
+            600, # h4 (semi-bold)
+            600, # h5 (semi-bold)
+            600, # h6 (semi-bold)
+        ]
+
+        If you specify an array with fewer than six weights, the unspecified
+        heading weights will be the default values. For example, you can use
+        the following array to set the font weights for h1-h2 headings while
+        keeping h3-h6 headings at their default weights:
+            headingFontWeights = [800, 700]
+
+        Setting a single value (not in an array) will set the font weight for
+        all h1-h6 headings to that value:
+            headingFontWeights = 500
+    """,
+)
+
+_create_theme_options(
+    "codeFont",
+    categories=["theme", CustomThemeCategories.SIDEBAR],
+    description="""
+        The font family to use for code (monospace) in the sidebar.
+
+        This can be one of the following:
+        - "sans-serif"
+        - "serif"
+        - "monospace"
+        - The `family` value for a custom font table under [[theme.fontFaces]]
+        - A comma-separated list of these (as a single string) to specify
+          fallbacks
+    """,
+)
+
+_create_theme_options(
+    "codeFontSize",
+    categories=["theme", CustomThemeCategories.SIDEBAR],
+    description="""
+        The font size (in pixels or rem) for code blocks and code text.
+
+        This applies to font in code blocks, `st.json`, and `st.help`. It
+        doesn't apply to inline code, which is set by default to 0.75em.
+
+        If this isn't set, the code font size will be 0.875rem.
+    """,
+)
+
+_create_theme_options(
+    "codeFontWeight",
+    categories=["theme", CustomThemeCategories.SIDEBAR],
+    description="""
+        The font weight for code blocks and code text.
+
+        This applies to font in inline code, code blocks, `st.json`, and
+        `st.help`. This is an integer multiple of 100. Values can be between
+        100 and 600, inclusive.
+
+        If this isn't set, the code font weight will be 400 (normal weight).
+    """,
+    type_=int,
+)
+
 _create_theme_options(
     "baseRadius",
     categories=["theme", CustomThemeCategories.SIDEBAR],
@@ -1275,7 +1459,7 @@ _create_theme_options(
         For example, you can use "10px", "0.5rem", or "2rem". To follow best
         practices, use rem instead of pixels when specifying a numeric size.
 
-        If no button radius is set, Streamlit uses `theme.baseRadius` instead.
+        If this isn't set, Streamlit uses `theme.baseRadius` instead.
     """,
 )
 
@@ -1293,8 +1477,21 @@ _create_theme_options(
     description="""
         The color of the border around dataframes and tables.
 
-        If no dataframe border color is set, Streamlit uses `theme.borderColor`
-        instead.
+        If this isn't set, Streamlit uses `theme.borderColor` instead.
+    """,
+)
+
+_create_theme_options(
+    "dataframeHeaderBackgroundColor",
+    categories=["theme", CustomThemeCategories.SIDEBAR],
+    description="""
+        The background color of the dataframe's header.
+
+        This color applies to all non-interior cells of the dataframe. This
+        includes the header row, the row-selection column (if present), and
+        the bottom row of data editors with a dynamic number of rows. If this
+        isn't set, Streamlit uses a mix of `theme.backgroundColor` and
+        `theme.secondaryBackgroundColor`.
     """,
 )
 
@@ -1307,19 +1504,6 @@ _create_theme_options(
     type_=bool,
 )
 
-_create_theme_options(
-    "baseFontSize",
-    categories=["theme"],
-    description="""
-        Sets the root font size (in pixels) for the app.
-
-        This determines the overall scale of text and UI elements.
-
-        When unset, the font size will be 16px.
-    """,
-    type_=int,
-)
-
 _create_theme_options(
     "showSidebarBorder",
     categories=["theme"],
@@ -1330,6 +1514,91 @@ _create_theme_options(
     type_=bool,
 )
 
+
+_create_theme_options(
+    "chartCategoricalColors",
+    categories=["theme"],
+    description="""
+        An array of colors to use for categorical chart data.
+
+        This is a list of one or more color strings which are applied in order
+        to categorical data. These colors apply to Plotly, Altair, and
+        Vega-Lite charts.
+
+        Invalid colors are skipped, and colors repeat cyclically if there are
+        more categories than colors. If no chart categorical colors are set,
+        Streamlit uses a default set of colors.
+
+        For light themes, the following colors are the default:
+        [
+            "#0068c9", # blue80
+            "#83c9ff", # blue40
+            "#ff2b2b", # red80
+            "#ffabab", # red40
+            "#29b09d", # blueGreen80
+            "#7defa1", # green40
+            "#ff8700", # orange80
+            "#ffd16a", # orange50
+            "#6d3fc0", # purple80
+            "#d5dae5", # gray40
+        ]
+        For dark themes, the following colors are the default:
+        [
+            "#83c9ff", # blue40
+            "#0068c9", # blue80
+            "#ffabab", # red40
+            "#ff2b2b", # red80
+            "#7defa1", # green40
+            "#29b09d", # blueGreen80
+            "#ffd16a", # orange50
+            "#ff8700", # orange80
+            "#6d3fc0", # purple80
+            "#d5dae5", # gray40
+        ]
+    """,
+)
+
+_create_theme_options(
+    "chartSequentialColors",
+    categories=["theme"],
+    description="""
+        An array of ten colors to use for sequential or continuous chart data.
+
+        The ten colors create a gradient color scale. These colors apply to
+        Plotly, Altair, and Vega-Lite charts.
+
+        Invalid color strings are skipped. If there are not exactly ten
+        valid colors specified, Streamlit uses a default set of colors.
+
+         For light themes, the following colors are the default:
+        [
+            "#e4f5ff", #blue10
+            "#c7ebff", #blue20
+            "#a6dcff", #blue30
+            "#83c9ff", #blue40
+            "#60b4ff", #blue50
+            "#3d9df3", #blue60
+            "#1c83e1", #blue70
+            "#0068c9", #blue80
+            "#0054a3", #blue90
+            "#004280", #blue100
+        ]
+        For dark themes, the following colors are the default:
+        [
+            "#004280", #blue100
+            "#0054a3", #blue90
+            "#0068c9", #blue80
+            "#1c83e1", #blue70
+            "#3d9df3", #blue60
+            "#60b4ff", #blue50
+            "#83c9ff", #blue40
+            "#a6dcff", #blue30
+            "#c7ebff", #blue20
+            "#e4f5ff", #blue10
+        ]
+    """,
+)
+
 # Config Section: Secrets #
 
 _create_section("secrets", "Secrets configuration.")
@@ -1661,7 +1930,7 @@ def get_config_options(
         # Short-circuit if config files were parsed while we were waiting on
         # the lock.
         if _config_options and not force_reparse:
-            return _config_options
+            return _config_options  # ty: ignore[invalid-return-type]
 
         old_options = _config_options
         _config_options = copy.deepcopy(_config_options_template)
@@ -1746,6 +2015,56 @@ def _set_development_mode() -> None:
     development.is_development_mode = get_option("global.developmentMode")
 
 
+def _parse_trusted_user_headers() -> None:
+    """Convert string-valued server.trustedUserHeaders to a dict.
+
+    If server.trustedUserHeaders is configured from an environment variable or from
+    the CLI, it will be a JSON string. Parse this and set the value to the resulting
+    dict, after validation.
+    """
+    options = get_config_options()
+    trusted_user_headers = options["server.trustedUserHeaders"]
+    if isinstance(trusted_user_headers.value, str):
+        try:
+            parsed_value = json.loads(trusted_user_headers.value)
+            # Validate that this is an object with string values.
+            if not isinstance(parsed_value, dict):
+                # Config validation is using RuntimeError deliberately; ignore warning
+                # about making this TypeError.
+                # ruff: noqa: TRY004
+                raise RuntimeError("server.trustedUserHeaders JSON must be an object")
+            for json_key, json_value in parsed_value.items():
+                if not isinstance(json_value, str):
+                    raise RuntimeError(
+                        "server.trustedUserHeaders JSON must only have string values. "
+                        f'got bad value for key "{json_key}": {json_value}'
+                    )
+            set_option(
+                "server.trustedUserHeaders",
+                parsed_value,
+                where_defined=trusted_user_headers.where_defined,
+            )
+        except json.JSONDecodeError as jde:
+            raise RuntimeError(
+                f"bad JSON value for server.trustedUserHeaders: {jde.msg}"
+            )
+
+    # Fetch the latest value, since we might've updated it from JSON.
+    final_config_value = options["server.trustedUserHeaders"].value
+    # Ensure no user keys are duplicated.
+    values = set()
+    bad_keys = []
+    for user_key in final_config_value.values():
+        if user_key in values:
+            bad_keys.append(user_key)
+        values.add(user_key)
+
+    if bad_keys:
+        raise RuntimeError(
+            f"server.trustedUserHeaders had multiple mappings for user key(s) {bad_keys}"
+        )
+
+
 def on_config_parsed(
     func: Callable[[], None], force_connect: bool = False, lock: bool = False
 ) -> Callable[[], None]:
@@ -1805,3 +2124,6 @@ def on_config_parsed(
 # may edit config options based on the values of other config options.
 on_config_parsed(_check_conflicts, lock=True)
 on_config_parsed(_set_development_mode)
+# Update server.trustedUserHeaders from any JSON string that was set. Take out the
+# lock, since this is mutating the config.
+on_config_parsed(_parse_trusted_user_headers, lock=True)
