@@ -23,7 +23,6 @@ from typing import TYPE_CHECKING, Final, Union, cast
 from typing_extensions import TypeAlias
 
 from streamlit import runtime, type_util, url_util
-from streamlit.elements.lib.form_utils import current_form_id
 from streamlit.elements.lib.layout_utils import WidthWithoutContent, validate_width
 from streamlit.elements.lib.subtitle_utils import process_subtitle_data
 from streamlit.elements.lib.utils import compute_and_register_element_id
@@ -41,7 +40,6 @@ if TYPE_CHECKING:
     from numpy import typing as npt
 
     from streamlit.delta_generator import DeltaGenerator
-    from streamlit.type_util import NumpyShape
 
 
 MediaData: TypeAlias = Union[
@@ -211,6 +209,7 @@ class MediaMixin:
             )
         coordinates = self.dg._get_delta_path_str()
         marshall_audio(
+            self.dg,
             coordinates,
             audio_proto,
             data,
@@ -220,7 +219,6 @@ class MediaMixin:
             end_time,
             loop,
             autoplay,
-            form_id=current_form_id(self.dg),
             width=width,
         )
         return self.dg._enqueue("audio", audio_proto)
@@ -390,6 +388,7 @@ class MediaMixin:
         video_proto = VideoProto()
         coordinates = self.dg._get_delta_path_str()
         marshall_video(
+            self.dg,
             coordinates,
             video_proto,
             data,
@@ -400,7 +399,6 @@ class MediaMixin:
             loop,
             autoplay,
             muted,
-            form_id=current_form_id(self.dg),
             width=width,
         )
         return self.dg._enqueue("video", video_proto)
@@ -484,7 +482,7 @@ def _marshall_av_media(
             return
         data_or_filename = read_data
     elif type_util.is_type(data, "numpy.ndarray"):
-        data_or_filename = cast("npt.NDArray[Any]", data).tobytes()
+        data_or_filename = data.tobytes()
     else:
         raise RuntimeError(f"Invalid binary data format: {type(data)}")
 
@@ -501,6 +499,7 @@ def _marshall_av_media(
 
 
 def marshall_video(
+    dg: DeltaGenerator,
     coordinates: str,
     proto: VideoProto,
     data: MediaData,
@@ -511,7 +510,6 @@ def marshall_video(
     loop: bool = False,
     autoplay: bool = False,
     muted: bool = False,
-    form_id: str | None = None,
     width: WidthWithoutContent = "stretch",
 ) -> None:
     """Marshalls a video proto, using url processors as needed.
@@ -556,9 +554,6 @@ def marshall_video(
     muted: bool
         Whether the video should play with the audio silenced. This can be used to
         enable autoplay without user interaction. Defaults to False.
-    form_id: str | None
-        The ID of the form that this element is placed in. Provide None if
-        the element is not placed in a form.
     width: int or "stretch"
         The width of the video player. This can be one of the following:
         - An int: The width in pixels, e.g. 200 for a width of 200 pixels.
@@ -644,7 +639,7 @@ def marshall_video(
             "video",
             # video does not yet allow setting a user-defined key
             user_key=None,
-            form_id=form_id,
+            dg=dg,
             url=proto.url,
             mimetype=mimetype,
             start_time=start_time,
@@ -709,7 +704,7 @@ def _validate_and_normalize(data: npt.NDArray[Any]) -> tuple[bytes, int]:
 
     transformed_data: npt.NDArray[Any] = np.array(data, dtype=float)
 
-    if len(cast("NumpyShape", transformed_data.shape)) == 1:
+    if len(transformed_data.shape) == 1:
         nchan = 1
     elif len(transformed_data.shape) == 2:
         # In wave files,channels are interleaved. E.g.,
@@ -764,6 +759,7 @@ def _maybe_convert_to_wav_bytes(data: MediaData, sample_rate: int | None) -> Med
 
 
 def marshall_audio(
+    dg: DeltaGenerator,
     coordinates: str,
     proto: AudioProto,
     data: MediaData,
@@ -773,7 +769,6 @@ def marshall_audio(
     end_time: int | None = None,
     loop: bool = False,
     autoplay: bool = False,
-    form_id: str | None = None,
     width: WidthWithoutContent = "stretch",
 ) -> None:
     """Marshalls an audio proto, using data and url processors as needed.
@@ -801,9 +796,6 @@ def marshall_audio(
     autoplay : bool
         Whether the audio should start playing automatically.
         Browsers will not autoplay audio files if the user has not interacted with the page yet.
-    form_id: str | None
-        The ID of the form that this element is placed in. Provide None if
-        the element is not placed in a form.
     width: int or "stretch"
         The width of the audio player. This can be one of the following:
         - An int: The width in pixels, e.g. 200 for a width of 200 pixels.
@@ -839,7 +831,7 @@ def marshall_audio(
         proto.id = compute_and_register_element_id(
             "audio",
             user_key=None,
-            form_id=form_id,
+            dg=dg,
             url=proto.url,
             mimetype=mimetype,
             start_time=start_time,
