@@ -59,7 +59,6 @@ from streamlit.runtime.metrics_util import gather_metrics
 from streamlit.runtime.scriptrunner_utils.script_run_context import get_script_run_ctx
 from streamlit.runtime.state import register_widget
 from streamlit.string_util import is_emoji, validate_material_icon
-from streamlit.type_util import T
 
 if TYPE_CHECKING:
     from streamlit.dataframe_util import OptionSequence
@@ -75,7 +74,7 @@ if TYPE_CHECKING:
         WidgetSerializer,
     )
 
-
+T = TypeVar("T")
 V = TypeVar("V")
 
 _THUMB_ICONS: Final = (":material/thumb_up:", ":material/thumb_down:")
@@ -340,8 +339,8 @@ class ButtonGroupMixin:
             An optional callback invoked when this feedback widget's value
             changes.
 
-        args : tuple
-            An optional tuple of args to pass to the callback.
+        args : list or tuple
+            An optional list or tuple of args to pass to the callback.
 
         kwargs : dict
             An optional dict of kwargs to pass to the callback.
@@ -562,8 +561,8 @@ class ButtonGroupMixin:
         on_change : callable
             An optional callback invoked when this widget's value changes.
 
-        args : tuple
-            An optional tuple of args to pass to the callback.
+        args : list or tuple
+            An optional list or tuple of args to pass to the callback.
 
         kwargs : dict
             An optional dict of kwargs to pass to the callback.
@@ -788,8 +787,8 @@ class ButtonGroupMixin:
         on_change : callable
             An optional callback invoked when this widget's value changes.
 
-        args : tuple
-            An optional tuple of args to pass to the callback.
+        args : list or tuple
+            An optional list or tuple of args to pass to the callback.
 
         kwargs : dict
             An optional dict of kwargs to pass to the callback.
@@ -1032,7 +1031,6 @@ class ButtonGroupMixin:
 
         check_widget_policies(self.dg, key, on_change, default_value=_default)
 
-        widget_name = "button_group"
         ctx = get_script_run_ctx()
         form_id = current_form_id(self.dg)
         formatted_options = (
@@ -1043,16 +1041,20 @@ class ButtonGroupMixin:
                 for index, _ in enumerate(indexable_options)
             ]
         )
+
         element_id = compute_and_register_element_id(
-            widget_name,
+            # The borderless style is used by st.feedback, but users expect to see
+            # "feedback" in errors
+            "feedback" if style == "borderless" else style,
             user_key=key,
-            form_id=form_id,
             dg=self.dg,
             options=formatted_options,
             default=default,
             click_mode=parsed_selection_mode,
             style=style,
             width=width,
+            label=label,
+            help=help,
         )
 
         proto = _build_proto(
@@ -1087,7 +1089,7 @@ class ButtonGroupMixin:
         if ctx:
             save_for_app_testing(ctx, element_id, format_func)
 
-        self.dg._enqueue(widget_name, proto, layout_config=layout_config)
+        self.dg._enqueue("button_group", proto, layout_config=layout_config)
 
         return widget_state
 
