@@ -26,6 +26,11 @@ from streamlit.elements.lib.file_uploader_utils import (
     normalize_upload_file_type,
 )
 from streamlit.elements.lib.form_utils import current_form_id
+from streamlit.elements.lib.layout_utils import (
+    LayoutConfig,
+    WidthWithoutContent,
+    validate_width,
+)
 from streamlit.elements.lib.policies import (
     check_widget_policies,
     maybe_raise_label_warnings,
@@ -62,6 +67,12 @@ SomeUploadedFiles: TypeAlias = Union[
     None,
 ]
 
+# Type alias for accept_multiple_files parameter.
+# If True, multiple files can be uploaded.
+# If False, only a single file can be uploaded.
+# If set to the literal "directory", users can upload an entire directory (folder) of files.
+AcceptMultipleFiles: TypeAlias = Union[bool, Literal["directory"]]
+
 
 def _get_upload_files(
     widget_value: FileUploaderStateProto | None,
@@ -99,12 +110,10 @@ def _get_upload_files(
 
 @dataclass
 class FileUploaderSerde:
-    accept_multiple_files: bool
+    accept_multiple_files: AcceptMultipleFiles
     allowed_types: Sequence[str] | None = None
 
-    def deserialize(
-        self, ui_value: FileUploaderStateProto | None, widget_id: str
-    ) -> SomeUploadedFiles:
+    def deserialize(self, ui_value: FileUploaderStateProto | None) -> SomeUploadedFiles:
         upload_files = _get_upload_files(ui_value)
 
         for file in upload_files:
@@ -114,12 +123,16 @@ class FileUploaderSerde:
             if self.allowed_types:
                 enforce_filename_restriction(file.name, self.allowed_types)
 
+        # Directory uploads always return a list, similar to multiple files
+        is_multiple_or_directory = (
+            self.accept_multiple_files is True
+            or self.accept_multiple_files == "directory"
+        )
+
         if len(upload_files) == 0:
-            return_value: SomeUploadedFiles = [] if self.accept_multiple_files else None
+            return_value: SomeUploadedFiles = [] if is_multiple_or_directory else None
         else:
-            return_value = (
-                upload_files if self.accept_multiple_files else upload_files[0]
-            )
+            return_value = upload_files if is_multiple_or_directory else upload_files[0]
         return return_value
 
     def serialize(self, files: SomeUploadedFiles) -> FileUploaderStateProto:
@@ -127,7 +140,7 @@ class FileUploaderSerde:
 
         if not files:
             return state_proto
-        elif not isinstance(files, list):
+        if not isinstance(files, list):
             files = [files]
 
         for f in files:
@@ -146,21 +159,22 @@ class FileUploaderMixin:
     # Multiple overloads are defined on `file_uploader()` below to represent
     # the different return types of `file_uploader()`.
     # These return types differ according to the value of the `accept_multiple_files` argument.
-    # There are 2 associated variables, each with 2 options.
-    # 1. The `accept_multiple_files` argument is set as `True`,
-    #    or it is set as `False` or omitted, in which case the default value `False`.
-    # 2. The `type` argument may or may not be provided as a keyword-only argument.
     # There must be 2x2=4 overloads to cover all the possible arguments,
     # as these overloads must be mutually exclusive for mypy.
+    # There are 3 associated variables, each with 2+ options.
+    # 1. The `accept_multiple_files` argument is set as `True` or `"directory"`,
+    #    or it is set as `False` or omitted, in which case the default value `False`.
+    # 2. The `type` argument may or may not be provided as a keyword-only argument.
+    # 3. Directory uploads always return a list of UploadedFile objects.
 
     # 1. type is given as not a keyword-only argument
-    # 2. accept_multiple_files = True
+    # 2. accept_multiple_files = True or "directory"
     @overload
     def file_uploader(
         self,
         label: str,
         type: str | Sequence[str] | None,
-        accept_multiple_files: Literal[True],
+        accept_multiple_files: Literal[True, "directory"],
         key: Key | None = None,
         help: str | None = None,
         on_change: WidgetCallback | None = None,
@@ -169,7 +183,8 @@ class FileUploaderMixin:
         *,
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
-    ) -> list[UploadedFile] | None: ...
+        width: WidthWithoutContent = "stretch",
+    ) -> list[UploadedFile]: ...
 
     # 1. type is given as not a keyword-only argument
     # 2. accept_multiple_files = False or omitted
@@ -187,6 +202,7 @@ class FileUploaderMixin:
         *,
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
+        width: WidthWithoutContent = "stretch",
     ) -> UploadedFile | None: ...
 
     # The following 2 overloads represent the cases where
@@ -195,13 +211,13 @@ class FileUploaderMixin:
     # for the related discussions and examples.
 
     # 1. type is skipped or a keyword argument
-    # 2. accept_multiple_files = True
+    # 2. accept_multiple_files = True or "directory"
     @overload
     def file_uploader(
         self,
         label: str,
         *,
-        accept_multiple_files: Literal[True],
+        accept_multiple_files: Literal[True, "directory"],
         type: str | Sequence[str] | None = None,
         key: Key | None = None,
         help: str | None = None,
@@ -210,7 +226,8 @@ class FileUploaderMixin:
         kwargs: WidgetKwargs | None = None,
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
-    ) -> list[UploadedFile] | None: ...
+        width: WidthWithoutContent = "stretch",
+    ) -> list[UploadedFile]: ...
 
     # 1. type is skipped or a keyword argument
     # 2. accept_multiple_files = False or omitted
@@ -228,6 +245,7 @@ class FileUploaderMixin:
         kwargs: WidgetKwargs | None = None,
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
+        width: WidthWithoutContent = "stretch",
     ) -> UploadedFile | None: ...
 
     @gather_metrics("file_uploader")
@@ -235,7 +253,7 @@ class FileUploaderMixin:
         self,
         label: str,
         type: str | Sequence[str] | None = None,
-        accept_multiple_files: bool = False,
+        accept_multiple_files: AcceptMultipleFiles = False,
         key: Key | None = None,
         help: str | None = None,
         on_change: WidgetCallback | None = None,
@@ -244,6 +262,7 @@ class FileUploaderMixin:
         *,  # keyword-only arguments:
         disabled: bool = False,
         label_visibility: LabelVisibility = "visible",
+        width: WidthWithoutContent = "stretch",
     ) -> UploadedFile | list[UploadedFile] | None:
         r"""Display a file uploader widget.
         By default, uploaded files are limited to 200 MB each. You can
@@ -277,7 +296,7 @@ class FileUploaderMixin:
             .. |st.markdown| replace:: ``st.markdown``
             .. _st.markdown: https://docs.streamlit.io/develop/api-reference/text/st.markdown
 
-        type : str or list of str or None
+        type : str, list of str, or None
             The allowed file extension(s) for uploaded files. This can be one
             of the following types:
 
@@ -288,11 +307,25 @@ class FileUploaderMixin:
               example, to only accept JPG/JPEG and PNG files, use
               ``["jpg", "jpeg", "png"]``.
 
-        accept_multiple_files : bool
-            Whether to accept more than one file in a submission. If this is
-            ``False`` (default), the user can only submit one file at a time.
-            If this is ``True``, the user can upload multiple files at the same
-            time, in which case the return value will be a list of files.
+            .. note::
+                This is a best-effort check, but doesn't provide a
+                security guarantee against users uploading files of other types
+                or type extensions. The correct handling of uploaded files is
+                part of the app developer's responsibility.
+
+        accept_multiple_files : bool or "directory"
+            Whether to accept more than one file in a submission. This can be one
+            of the following values:
+
+            - ``False`` (default): The user can only submit one file at a time.
+            - ``True``: The user can upload multiple files at the same time.
+            - ``"directory"``: The user can select a directory to upload all
+              files in the directory and its subdirectories. If ``type`` is
+              set, only files matching those type(s) will be uploaded.
+
+            When this is ``True`` or ``"directory"``, the return value will be
+            a list and a user can additively select files if they click the
+            browse button on the widget multiple times.
 
         key : str or int
             An optional string or integer to use as the unique key for the widget.
@@ -312,8 +345,8 @@ class FileUploaderMixin:
             An optional callback invoked when this file_uploader's value
             changes.
 
-        args : tuple
-            An optional tuple of args to pass to the callback.
+        args : list or tuple
+            An optional list or tuple of args to pass to the callback.
 
         kwargs : dict
             An optional dict of kwargs to pass to the callback.
@@ -325,25 +358,36 @@ class FileUploaderMixin:
         label_visibility : "visible", "hidden", or "collapsed"
             The visibility of the label. The default is ``"visible"``. If this
             is ``"hidden"``, Streamlit displays an empty spacer instead of the
-            label, which can help keep the widget alligned with other widgets.
+            label, which can help keep the widget aligned with other widgets.
             If this is ``"collapsed"``, Streamlit displays no label or spacer.
 
+        width : "stretch" or int
+            The width of the file uploader widget. This can be one of the
+            following:
+
+            - ``"stretch"`` (default): The width of the widget matches the
+              width of the parent container.
+            - An integer specifying the width in pixels: The widget has a
+              fixed width. If the specified width is greater than the width of
+              the parent container, the width of the widget matches the width
+              of the parent container.
+
         Returns
         -------
         None, UploadedFile, or list of UploadedFile
-            - If accept_multiple_files is False, returns either None or
-              an UploadedFile object.
-            - If accept_multiple_files is True, returns a list with the
-              uploaded files as UploadedFile objects. If no files were
-              uploaded, returns an empty list.
+            - If accept_multiple_files is ``False``, returns either ``None`` or
+              an ``UploadedFile`` object.
+            - If accept_multiple_files is ``True`` or ``"directory"``, returns
+              a list with the uploaded files as ``UploadedFile`` objects. If no
+              files were uploaded, returns an empty list.
 
-            The UploadedFile class is a subclass of BytesIO, and therefore is
-            "file-like". This means you can pass an instance of it anywhere a
-            file is expected.
+            The ``UploadedFile`` class is a subclass of ``BytesIO``, and
+            therefore is "file-like". This means you can pass an instance of it
+            anywhere a file is expected.
 
         Examples
         --------
-        Insert a file uploader that accepts a single file at a time:
+        **Example 1: Accept a single file at a time**
 
         >>> import streamlit as st
         >>> import pandas as pd
@@ -367,20 +411,34 @@ class FileUploaderMixin:
         ...     dataframe = pd.read_csv(uploaded_file)
         ...     st.write(dataframe)
 
-        Insert a file uploader that accepts multiple files at a time:
+        **Example 2: Accept multiple files at a time**
+
+        >>> import pandas as pd
+        >>> import streamlit as st
+        >>>
+        >>> uploaded_files = st.file_uploader(
+        ...     "Upload data", accept_multiple_files=True, type="csv"
+        ... )
+        >>> for uploaded_file in uploaded_files:
+        ...     df = pd.read_csv(uploaded_file)
+        ...     st.write(df)
+
+        .. output::
+           https://doc-file-uploader.streamlit.app/
+           height: 375px
+
+        **Example 3: Accept an entire directory**
 
         >>> import streamlit as st
         >>>
         >>> uploaded_files = st.file_uploader(
-        ...     "Choose a CSV file", accept_multiple_files=True
+        ...     "Upload images", accept_multiple_files="directory", type=["jpg", "png"]
         ... )
         >>> for uploaded_file in uploaded_files:
-        ...     bytes_data = uploaded_file.read()
-        ...     st.write("filename:", uploaded_file.name)
-        ...     st.write(bytes_data)
+        ...     st.image(uploaded_file)
 
         .. output::
-           https://doc-file-uploader.streamlit.app/
+           https://doc-file-uploader-directory.streamlit.app/
            height: 375px
 
         """
@@ -396,6 +454,7 @@ class FileUploaderMixin:
             kwargs=kwargs,
             disabled=disabled,
             label_visibility=label_visibility,
+            width=width,
             ctx=ctx,
         )
 
@@ -403,7 +462,7 @@ class FileUploaderMixin:
         self,
         label: str,
         type: str | Sequence[str] | None = None,
-        accept_multiple_files: bool = False,
+        accept_multiple_files: AcceptMultipleFiles = False,
         key: Key | None = None,
         help: str | None = None,
         on_change: WidgetCallback | None = None,
@@ -413,6 +472,7 @@ class FileUploaderMixin:
         label_visibility: LabelVisibility = "visible",
         disabled: bool = False,
         ctx: ScriptRunContext | None = None,
+        width: WidthWithoutContent = "stretch",
     ) -> UploadedFile | list[UploadedFile] | None:
         key = to_key(key)
 
@@ -428,24 +488,31 @@ class FileUploaderMixin:
         element_id = compute_and_register_element_id(
             "file_uploader",
             user_key=key,
-            form_id=current_form_id(self.dg),
+            dg=self.dg,
             label=label,
             type=type,
             accept_multiple_files=accept_multiple_files,
             help=help,
+            width=width,
         )
 
-        if type:
-            type = normalize_upload_file_type(type)
+        normalized_type = normalize_upload_file_type(type) if type else None
 
         file_uploader_proto = FileUploaderProto()
         file_uploader_proto.id = element_id
         file_uploader_proto.label = label
-        file_uploader_proto.type[:] = type if type is not None else []
+        file_uploader_proto.type[:] = (
+            normalized_type if normalized_type is not None else []
+        )
         file_uploader_proto.max_upload_size_mb = config.get_option(
             "server.maxUploadSize"
         )
-        file_uploader_proto.multiple_files = accept_multiple_files
+        # Handle directory uploads - they should enable multiple files and set the directory flag
+        is_directory_upload = accept_multiple_files == "directory"
+        file_uploader_proto.multiple_files = (
+            accept_multiple_files is True or is_directory_upload
+        )
+        file_uploader_proto.accept_directory = is_directory_upload
         file_uploader_proto.form_id = current_form_id(self.dg)
         file_uploader_proto.disabled = disabled
         file_uploader_proto.label_visibility.value = get_label_visibility_proto_value(
@@ -455,7 +522,7 @@ class FileUploaderMixin:
         if help is not None:
             file_uploader_proto.help = dedent(help)
 
-        serde = FileUploaderSerde(accept_multiple_files, allowed_types=type)
+        serde = FileUploaderSerde(accept_multiple_files, allowed_types=normalized_type)
 
         # FileUploader's widget value is a list of file IDs
         # representing the current set of files that this uploader should
@@ -471,11 +538,16 @@ class FileUploaderMixin:
             value_type="file_uploader_state_value",
         )
 
-        self.dg._enqueue("file_uploader", file_uploader_proto)
+        validate_width(width)
+        layout_config = LayoutConfig(width=width)
+
+        self.dg._enqueue(
+            "file_uploader", file_uploader_proto, layout_config=layout_config
+        )
 
         if isinstance(widget_state.value, DeletedFile):
             return None
-        elif isinstance(widget_state.value, list):
+        if isinstance(widget_state.value, list):
             return [f for f in widget_state.value if not isinstance(f, DeletedFile)]
 
         return widget_state.value
