@@ -21,10 +21,6 @@ from copy import deepcopy
 from functools import wraps
 from typing import TYPE_CHECKING, Any, Callable, Protocol, TypeVar, overload
 
-from streamlit.deprecation_util import (
-    make_deprecated_name_warning,
-    show_deprecation_warning,
-)
 from streamlit.error_util import handle_uncaught_app_exception
 from streamlit.errors import FragmentHandledException, FragmentStorageKeyError
 from streamlit.proto.ForwardMsg_pb2 import ForwardMsg
@@ -35,6 +31,7 @@ from streamlit.runtime.scriptrunner_utils.exceptions import (
 )
 from streamlit.runtime.scriptrunner_utils.script_run_context import get_script_run_ctx
 from streamlit.time_util import time_to_seconds
+from streamlit.type_util import get_object_name
 from streamlit.util import calc_md5
 
 if TYPE_CHECKING:
@@ -137,7 +134,6 @@ def _fragment(
     *,
     run_every: int | float | timedelta | str | None = None,
     additional_hash_info: str = "",
-    should_show_deprecation_warning: bool = False,
 ) -> Callable[[F], F] | F:
     """Contains the actual fragment logic.
 
@@ -155,7 +151,7 @@ def _fragment(
             )
 
         return wrapper
-    non_optional_func = func
+    non_optional_func: F = func
 
     @wraps(non_optional_func)
     def wrap(*args: Any, **kwargs: Any) -> Any:
@@ -168,7 +164,7 @@ def _fragment(
         cursors_snapshot = deepcopy(ctx.cursors)
         dg_stack_snapshot = deepcopy(context_dg_stack.get())
         fragment_id = calc_md5(
-            f"{non_optional_func.__module__}.{non_optional_func.__qualname__}{dg_stack_snapshot[-1]._get_delta_path_str()}{additional_hash_info}"
+            f"{non_optional_func.__module__}.{get_object_name(non_optional_func)}{dg_stack_snapshot[-1]._get_delta_path_str()}{additional_hash_info}"
         )
 
         # We intentionally want to capture the active script hash here to ensure
@@ -178,15 +174,6 @@ def _fragment(
         def wrapped_fragment() -> Any:
             import streamlit as st
 
-            if should_show_deprecation_warning:
-                show_deprecation_warning(
-                    make_deprecated_name_warning(
-                        "experimental_fragment",
-                        "fragment",
-                        "2025-01-01",
-                    )
-                )
-
             # NOTE: We need to call get_script_run_ctx here again and can't just use the
             # value of ctx from above captured by the closure because subsequent
             # fragment runs will generally run in a new script run, thus we'll have a
@@ -448,31 +435,3 @@ def fragment(
 
     """
     return _fragment(func, run_every=run_every)
-
-
-@overload
-def experimental_fragment(
-    func: F,
-    *,
-    run_every: int | float | timedelta | str | None = None,
-) -> F: ...
-
-
-# Support being able to pass parameters to this decorator (that is, being able to write
-# `@fragment(run_every=5.0)`).
-@overload
-def experimental_fragment(
-    func: None = None,
-    *,
-    run_every: int | float | timedelta | str | None = None,
-) -> Callable[[F], F]: ...
-
-
-@gather_metrics("experimental_fragment")
-def experimental_fragment(
-    func: F | None = None,
-    *,
-    run_every: int | float | timedelta | str | None = None,
-) -> Callable[[F], F] | F:
-    """Deprecated alias for @st.fragment. See the docstring for the decorator's new name."""
-    return _fragment(func, run_every=run_every, should_show_deprecation_warning=True)
